@@ -2,8 +2,8 @@ use std::time::Duration;
 
 use tokio::time;
 
-#[tokio::main]
-pub async fn main() {
+#[selectme::main]
+pub(crate) async fn main() {
     let s1 = time::sleep(Duration::from_millis(100));
     tokio::pin!(s1);
     let mut s1_done = false;
