@@ -3,7 +3,7 @@ use std::time::Duration;
 use tokio::time;
 
 #[selectme::main(flavor = "current_thread")]
-pub async fn main() {
+pub(crate) async fn main() {
     let s1 = time::sleep(Duration::from_millis(100));
     let s2 = time::sleep(Duration::from_millis(200));
 
