@@ -3,8 +3,8 @@ use std::time::Duration;
 use selectme::{Random, StaticSelect};
 use tokio::time::{self, Sleep};
 
-#[tokio::main]
-pub async fn main() {
+#[selectme::main]
+pub(crate) async fn main() {
     let s1 = time::sleep(Duration::from_millis(100));
     let s2 = time::sleep(Duration::from_millis(200));
 
