@@ -1,3 +1,4 @@
+use core::fmt;
 use core::future::Future;
 use core::pin::Pin;
 use core::task::{Context, Poll};
@@ -26,7 +27,7 @@ pub const DISABLED: u32 = u32::MAX;
 /// use selectme::{Random, Select};
 /// use tokio::time;
 ///
-/// # #[tokio::main] pub async fn main() {
+/// # #[selectme::main] pub(crate) async fn main() {
 /// let s1 = time::sleep(Duration::from_millis(100));
 /// let s2 = time::sleep(Duration::from_millis(200));
 ///
@@ -52,16 +53,16 @@ pub const DISABLED: u32 = u32::MAX;
 /// ```
 
 pub struct Select<Bits, S, B, T> {
-    snapshot: Set<Bits>,
+    enabled: Set<Bits>,
     state: S,
     bias: B,
     poll: T,
 }
 
 impl<Bits, S, B, T> Select<Bits, S, B, T> {
-    pub(crate) fn new(snapshot: Set<Bits>, bias: B, state: S, poll: T) -> Self {
+    pub(crate) fn new(enabled: Set<Bits>, bias: B, state: S, poll: T) -> Self {
         Self {
-            snapshot,
+            enabled,
             state,
             bias,
             poll,
@@ -84,8 +85,8 @@ where
     ///
     /// use tokio::time;
     ///
-    /// #[tokio::main]
-    /// pub async fn main() {
+    /// #[selectme::main]
+    /// pub(crate) async fn main() {
     ///     let s1 = time::sleep(Duration::from_millis(100));
     ///     let s2 = time::sleep(Duration::from_millis(200));
     ///
@@ -118,9 +119,9 @@ where
             let mut state = Pin::new_unchecked(&mut this.state);
 
             // All branches are disabled.
-            for index in this.bias.apply(this.snapshot) {
+            for index in this.bias.apply(this.enabled) {
                 if let Poll::Ready(output) =
-                    (this.poll)(cx, state.as_mut(), &mut this.snapshot, index)
+                    (this.poll)(cx, state.as_mut(), &mut this.enabled, index)
                 {
                     return Poll::Ready(output);
                 }
@@ -128,8 +129,8 @@ where
 
             // We've polled through all branches (and they have been disabled
             // through pattern matching).
-            if this.snapshot.is_empty() {
-                return (this.poll)(cx, state.as_mut(), &mut this.snapshot, DISABLED);
+            if this.enabled.is_empty() {
+                return (this.poll)(cx, state.as_mut(), &mut this.enabled, DISABLED);
             }
 
             Poll::Pending
@@ -166,3 +167,18 @@ where
         unsafe { Pin::get_unchecked_mut(self).this.as_mut().poll_next(cx) }
     }
 }
+
+impl<Bits, S, B, O> fmt::Debug for Select<Bits, S, B, O>
+where
+    Bits: Number,
+    B: fmt::Debug,
+    S: fmt::Debug,
+{
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        f.debug_struct("Select")
+            .field("enabled", &self.enabled)
+            .field("state", &self.state)
+            .field("bias", &self.bias)
+            .finish()
+    }
+}
